Class: Javonet
- Inherits:
-
Object
- Object
- Javonet
- Defined in:
- lib/javonet-ruby-sdk.rb
Overview
The Javonet class is a singleton class that serves as the entry point for interacting with Javonet. It provides methods to activate and initialize the Javonet SDK. It supports both in-memory and TCP connections.
Class Method Summary collapse
-
.activate(licence_key, proxy_host = "", proxy_user_name = "", proxy_password = "") ⇒ Integer
Activates Javonet with the provided license key and optionally with proxy data.
-
.in_memory ⇒ RuntimeFactory
Initializes Javonet using an in-memory channel on the same machine.
-
.tcp(address) ⇒ RuntimeFactory
Initializes Javonet with a TCP connection to a remote machine.
Class Method Details
.activate(licence_key, proxy_host = "", proxy_user_name = "", proxy_password = "") ⇒ Integer
Activates Javonet with the provided license key and optionally with proxy data.
38 39 40 |
# File 'lib/javonet-ruby-sdk.rb', line 38 def self.activate(licence_key, proxy_host="", proxy_user_name="", proxy_password="") return Transmitter.activate_with_credentials_and_proxy(licence_key, proxy_host, proxy_user_name, proxy_password) end |
.in_memory ⇒ RuntimeFactory
Initializes Javonet using an in-memory channel on the same machine.
16 17 18 19 |
# File 'lib/javonet-ruby-sdk.rb', line 16 def self.in_memory connection_type = ConnectionType::IN_MEMORY return RuntimeFactory.new(connection_type) end |
.tcp(address) ⇒ RuntimeFactory
Initializes Javonet with a TCP connection to a remote machine.
25 26 27 28 |
# File 'lib/javonet-ruby-sdk.rb', line 25 def self.tcp(address) connection_type = ConnectionType::TCP return RuntimeFactory.new(connection_type, address) end |